onLongPressHitTestResult property

  1. @SupportedPlatforms.new(platforms: [AndroidPlatform(apiName: 'View.setOnLongClickListener', apiUrl: 'https://developer.android.com/reference/android/view/View#setOnLongClickListener(android.view.View.OnLongClickListener)'), IOSPlatform(apiName: 'UILongPressGestureRecognizer', apiUrl: 'https://developer.apple.com/documentation/uikit/uilongpressgesturerecognizer')])
void Function(dynamic controller, InAppWebViewHitTestResult hitTestResult)? onLongPressHitTestResult
finalinherited

Event fired when an HTML element of the webview has been clicked and held.

hitTestResult represents the hit result for hitting an HTML elements.

Officially Supported Platforms/Implementations:

Parameters - Officially Supported Platforms/Implementations:

  • hitTestResult: all platforms

Use the PlatformWebViewCreationParams.isPropertySupported method to check if this property is supported at runtime.

Implementation

@SupportedPlatforms(
  platforms: [
    AndroidPlatform(
      apiName: 'View.setOnLongClickListener',
      apiUrl:
          'https://developer.android.com/reference/android/view/View#setOnLongClickListener(android.view.View.OnLongClickListener)',
    ),
    IOSPlatform(
      apiName: 'UILongPressGestureRecognizer',
      apiUrl:
          'https://developer.apple.com/documentation/uikit/uilongpressgesturerecognizer',
    ),
  ],
)
final void Function(T controller, InAppWebViewHitTestResult hitTestResult)?
onLongPressHitTestResult;