AndroidInternalStoragePathHandlerCreationParams class

Object specifying creation parameters for creating a AndroidInternalStoragePathHandler.

When adding additional fields make sure they can be null or have a default value to avoid breaking changes. See PlatformInternalStoragePathHandlerCreationParams for more information.

Annotations

Constructors

AndroidInternalStoragePathHandlerCreationParams(PlatformInternalStoragePathHandlerCreationParams params)
Creates a new AndroidInternalStoragePathHandlerCreationParams instance.
AndroidInternalStoragePathHandlerCreationParams.fromPlatformInternalStoragePathHandlerCreationParams(PlatformInternalStoragePathHandlerCreationParams params)
Creates a AndroidInternalStoragePathHandlerCreationParams instance based on PlatformInternalStoragePathHandlerCreationParams.
factory

Properties

directory → String
The directory for which files should be served.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
path → String
{@macro flutter_inappwebview_platform_interface.PlatformPathHandler.path}
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited