AndroidTracingControllerCreationParams class

Object specifying creation parameters for creating a AndroidTracingController.

When adding additional fields make sure they can be null or have a default value to avoid breaking changes. See PlatformTracingControllerCreationParams for more information.

Annotations

Constructors

AndroidTracingControllerCreationParams(PlatformTracingControllerCreationParams params)
Creates a new AndroidTracingControllerCreationParams instance.
const
AndroidTracingControllerCreationParams.fromPlatformTracingControllerCreationParams(PlatformTracingControllerCreationParams params)
Creates a AndroidTracingControllerCreationParams instance based on PlatformTracingControllerCreationParams.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited