contextMenu property
- @SupportedPlatforms.new(platforms: [AndroidPlatform(), IOSPlatform()])
finalinherited
Context menu which contains custom menu items to be shown when ContextMenu is presented.
Officially Supported Platforms/Implementations:
- Android WebView
- iOS WKWebView
Use the PlatformWebViewCreationParams.isPropertySupported method to check if this property is supported at runtime.
Implementation
@SupportedPlatforms(platforms: [AndroidPlatform(), IOSPlatform()])
final ContextMenu? contextMenu;